@@ -6,7 +6,7 @@ fi
 
 APACI_DIR=$ROOT/opt/httpd
 
-( cd $ROOT/opt/htdocs; rm -f squirrelmail; ln -sf squirrelmail-1.4.19 squirrelmail; )
+( cd $ROOT/opt/htdocs; rm -f squirrelmail; ln -sf squirrelmail-1.4.21 squirrelmail; )
 
 NNAME=`/bin/hostname -f`
 if [ ".$NNAME" = "." ]; then
@@ -15,6 +15,7 @@ fi
 (cd $ROOT/opt/htdocs/squirrelmail/; \
     sed -e "s/example.com/$NNAME/" config/config_plamo.php > config/config.php  )
 
-mkdir -p $ROOT/var/squirrelmail/{attach,data}
+mkdir -p $ROOT/var/squirrelmail/attach
+mkdir -p $ROOT/var/squirrelmail/data
 /bin/chown -R www:apache $ROOT/var/squirrelmail
 
